package GUI::ResourceEditor;

use strict;
use vars qw($VERSION @ISA);
use Tk;
use RMA::Resource;

use GUI::Help;

use Class::MethodMaker
  new_with_init => 'new',
  new_hash_init => 'hash_init',
  get_set => [ 'title', 'resource', 'state', 'change_command', 'cancel_command'],
  hash => [ 'interface' ],
;

$VERSION = '0.01';

sub init {
  my $self = shift;
  $self->hash_init(@_);

  # initialize managed data
  $self->init_data;

  # initialize the window
  $self->init_window;

  return $self;
}

sub init_data {
  my $self = shift;

  # if we weren't passed a resource to edit, make a new one
  # reflect that in the title if it ain't set
  if (!defined($self->resource)) {
    $self->resource(RMA::Resource->new);
    if (!defined($self->title)) {
      $self->title('Resource Editor : New Resource');
    }
  }

  return $self;
}

sub init_window {
  my $self = shift;

  my $interface = $self->interface;
  if (!exists($interface->{top})) {
    $interface->{top} = MainWindow->new();
  } 
  # get rid of any existing contents if passed a toplevel
  my $top = $interface->{top};
  $top->geometry('+100+100');

  # setup the title
  if (defined($self->title)) {
    $top->title($self->title);
  } else {
    $top->title('Resource Editor');
  }

  my $main_frame = $top->Frame()->grid(-row => 0, -column => 0, -sticky => 'nsew');
  $interface->{main_frame} = $main_frame;
  my $button_frame = $top->Frame()->grid(-row => 1, -column => 0, -sticky => 'sew');
  $self->interface('button_frame', $button_frame);

  $top->gridRowconfigure(0, -weight => 1);
  $top->gridRowconfigure(1, -weight => 0);
  $top->gridColumnconfigure(0, -weight => 1);

  my $name_frame = $main_frame->Frame(-border => 3, -relief => 'ridge');
  my $name_label = $name_frame->Label(-text => 'Resource Name');
  my $name_entry = $name_frame->Entry();
  my $name_help = $name_frame->Button(-text => '?', 
                                      command => 
                                      [\&showHelp, 'ResourceEditor#name']
                                     );
  $name_entry->insert(0, $self->resource()->name());

  $name_label->grid(-row => 0, -column => 0, -sticky => 'nw');
  $name_entry->grid(-row => 1, -column => 0, -sticky => 'sew');
  $name_help->grid(-row => 1, -column => 1, -sticky => 'se');

  $name_frame->gridRowconfigure(0, -weight => 1);
  $name_frame->gridRowconfigure(1, -weight => 0);
  $name_frame->gridColumnconfigure(0, -weight => 1);
  $name_frame->gridColumnconfigure(1, -weight => 0);

  $self->interface('saved_policy', $self->resource->policy);

  my $policy_frame = $main_frame->Frame(-border => 3, -relief => 'ridge');
  my $policy_label = $policy_frame->Label(-text => 'Policy');
  my $policy_list = $policy_frame->Listbox(-width=>30, -height=> 5, -exportselection => 0);
  $policy_list->insert('end', "Interupt Masking (IMP)", "Priority Inheritence (PIP)", "Highest Locker", "Priority Ceiling (PCP)", "FIFO");
  if (!defined($self->resource->policy)) {
    $policy_list->selectionSet(0);
    $self->resource->policy('Interupt Masking (IMP)');
  } elsif ($self->resource->policy eq 'Interupt Masking (IMP)') {
    $policy_list->selectionSet(0);
  } elsif ($self->resource->policy eq 'Priority Inheritence (PIP)') {
    $policy_list->selectionSet(1);
  } elsif ($self->resource->policy eq 'Highest Locker') {
    $policy_list->selectionSet(2);
  } elsif ($self->resource->policy eq 'Priority Ceiling (PCP)') {
    $policy_list->selectionSet(3);
  } elsif ($self->resource->policy eq 'FIFO')  {
    $policy_list->selectionSet(4);
  } else {
    $policy_list->selectionSet(0);
    $self->resource->policy('Interupt Masking (IMP)');
  }

  $policy_list->bind('<Button-1>', 
                      sub {
                        my $policy = $policy_list->get($policy_list->curselection);
                        if (!$policy) {
                          $policy_list->selectionSet(0);
                          $policy = 'File';
                        } 
                        $self->resource->policy($policy);
                      }
                     );
                        
  my $policy_help = $policy_frame->Button(-text => '?', -command => [\&showHelp, 'ResourceEditor#policy']);

  $policy_label->grid(-row => 0, -column => 0, -sticky => 'nw');
  $policy_list->grid(-row => 1, -column => 0, -sticky => 'sew');
  $policy_help->grid(-row => 1, -column => 1, -sticky => 'se');

  $policy_frame->gridRowconfigure(0, -weight => 1);
  $policy_frame->gridRowconfigure(1, -weight => 0);
  $policy_frame->gridColumnconfigure(0, -weight => 1);
  $policy_frame->gridColumnconfigure(1, -weight => 0);

  $name_frame->grid(-row => 0, -column => 0 , -columnspan => 2, -sticky => 'nsew', -padx => 3, -pady => 5);
  $policy_frame->grid(-row => 1, -column => 0 , -sticky => 'nsew', -padx => 3, -pady => 5);


  $main_frame->gridColumnconfigure(0, -weight => 1);
  $main_frame->gridColumnconfigure(1, -weight => 1);
  $main_frame->gridRowconfigure(0, -weight => 1);
  $main_frame->gridRowconfigure(1, -weight => 1);

  $button_frame->Button(-text => 'Ok', -command => sub {
                          $self->resource->name($name_entry->get);
                          $top->destroy;
                          my $callback = $self->change_command;
                          defined($callback) && (&$callback ());
                        }
                       )->grid(-row => 0, -column => 0, -sticky => 'nsew');

  $button_frame->Button(-text => 'Cancel', -command => sub {
                          $self->resource->policy($self->interface('saved_policy'));
                          $top->destroy;
                          my $callback = $self->cancel_command;
                          defined($callback) && (&$callback ());
                        }
                       )->grid(-row => 0, -column => 1, -sticky => 'nsew');

  $button_frame->gridRowconfigure(0, -weight => 1);
  $button_frame->gridColumnconfigure(0, -weight => 1);
  $button_frame->gridColumnconfigure(1, -weight => 1);

  $top->update;
  return $self;
}


1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

GUI::ResourceEditor - Perl extension for blah blah blah

=head1 SYNOPSIS

  use GUI::ResourceEditor;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for GUI::ResourceEditor was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head1 AUTHOR

A. U. Thor, a.u.thor@a.galaxy.far.far.away

=head1 SEE ALSO

perl(1).

=cut
