package GUI::ResourceUsageEditor;


use strict;
use vars qw($VERSION @ISA);
use Tk;
use RMA::Task;

use GUI::Help;

use Class::MethodMaker
  new_with_init => 'new',
  new_hash_init => 'hash_init',
  get_set => [ 'title', 'task', 'resource_id', 'change_command', 'cancel_command'],
  hash => [ 'interface' ],
;

$VERSION = '0.01';

sub init {
  my $self = shift;
  $self->hash_init(@_);

  # initialize the window
  $self->init_window;

  return $self;
}

sub init_window {
  my $self = shift;
  my $task = $self->task;
  my $resource_id = $self->resource_id;
  my $resources = $self->task->resources;

  my $interface = $self->interface;
  if (!exists($interface->{top})) {
    $interface->{top} = MainWindow->new();
  } 
  # get rid of any existing contents if passed a toplevel
  my $top = $interface->{top};
  $top->geometry('+100+100');

  # setup the title
  if (defined($self->title)) {
    $top->title($self->title);
  } else {
    $top->title('Resource Usage Editor');
  }

  my $main_frame = $top->Frame()->grid(-row => 0, -column => 0, -sticky => 'nsew');
  $interface->{main_frame} = $main_frame;
  my $button_frame = $top->Frame()->grid(-row => 1, -column => 0, -sticky => 'sew');
  $self->interface('button_frame', $button_frame);

  $top->gridRowconfigure(0, -weight => 1);
  $top->gridRowconfigure(1, -weight => 0);
  $top->gridColumnconfigure(0, -weight => 1);

  my $time_frame = $main_frame->Frame(-border => 3, -relief => 'ridge');
  my $time_label = $time_frame->Label(-text => 'Maximum Usage Time Per Run');
  my $time_entry = $time_frame->Entry(-width => 4);
  my $time_help = $time_frame->Button(-text => '?', 
                                      command => 
                                      [\&showHelp, 'help.html#time']
                                     );
  if (!exists($resources->{$resource_id}{time}) || 
      !defined($resources->{$resource_id}{time})) {
    $resources->{$resource_id}{time} = 0;
  }

  $time_entry->insert(0, $resources->{$resource_id}{time});

  $time_label->grid(-row => 0, -column => 0, -sticky => 'nw');
  $time_entry->grid(-row => 1, -column => 0, -sticky => 'sew');
  $time_help->grid(-row => 1, -column => 1, -sticky => 'se');

  $time_frame->gridRowconfigure(0, -weight => 1);
  $time_frame->gridRowconfigure(1, -weight => 0);
  $time_frame->gridColumnconfigure(0, -weight => 1);
  $time_frame->gridColumnconfigure(1, -weight => 0);

  $time_frame->grid(-row => 0, -column => 0 , -columnspan => 2, -sticky => 'nsew', -padx => 3, -pady => 5);

  $main_frame->gridColumnconfigure(0, -weight => 1);
  $main_frame->gridColumnconfigure(1, -weight => 1);
  $main_frame->gridRowconfigure(0, -weight => 1);
    
  $button_frame->Button(-text => 'Ok', -command => sub {
                          $resources->{$resource_id}{time} = $time_entry->get;
                          $top->destroy;
                          my $callback = $self->change_command;
                          defined($callback) && (&$callback ());
                        }
                       )->grid(-row => 0, -column => 0, -sticky => 'nsew');

  $button_frame->Button(-text => 'Cancel', -command => sub {
                          $top->destroy;
                          my $callback = $self->cancel_command;
                          defined($callback) && (&$callback ());
                        }
                       )->grid(-row => 0, -column => 1, -sticky => 'nsew');

  $button_frame->gridRowconfigure(0, -weight => 1);
  $button_frame->gridColumnconfigure(0, -weight => 1);
  $button_frame->gridColumnconfigure(1, -weight => 1);

  $top->update;
  return $self;
}


1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

GUI::ResourceUsageEditor - Perl extension for blah blah blah

=head1 SYNOPSIS

  use GUI::ResourceUsageEditor;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for GUI::ResourceUsageEditor was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head1 AUTHOR

A. U. Thor, a.u.thor@a.galaxy.far.far.away

=head1 SEE ALSO

perl(1).

=cut
