package RMA::Resource;

=head1 NAME

RMA::Resource - Perl class representing a single Resource in the RMA system.

=head1 SYNOPSIS

  use RMA::Resource;
  my $resource = Resource->new(name => 'Database One');
  my $resource_id = $resource->id;

  # later...
  my $found_resource = Resource->find($resource_id);
  
=head1 DESCRIPTION

This class represents a single resource in the RMA system.  It is
"pointed to" by RMA::Task objects.

=cut

use Class::MethodMaker
  new_with_init => 'new',
  new_hash_init => '_hash_init',
  key_attrib => 'id',
  get_set => [ 'name', 'policy' ],
;

use Carp;

use strict;
use vars qw($VERSION @ISA);

$VERSION = '0.01';

use RMA::Object;
@ISA = qw(RMA::Object);

# handles setting up id if necessary and calling _hash_init

sub init {
  my $self = shift;
  @_ = $self->SUPER::init(@_);
  $self->_hash_init(@_);

  defined($self->name) || $self->name('');
  defined($self->policy) || $self->policy('Interupt Masking (IMP)');
}

1;

=head1 AUTHOR

Sam Tregar, sam@tregar.com

=cut
