package RMA::System;

=head1 NAME

RMA::System - Perl class representing a single System in the RMA modules

=head1 SYNOPSIS

  use RMA::System;
  my $resource = RMA::System->new(name => 'System One');
  
=head1 DESCRIPTION

This object represents a single real time system for the purpose of
the RMA module system.  A system contains a list of task_ids and
resource_ids that have been assigned to it.  It is pointed to to be an
instance of RMA::Analyzer which works on it as input for analysis.

=cut

use Class::MethodMaker
  new_with_init => 'new',
  new_hash_init => '_hash_init',
  key_attrib => 'id',
  get_set => 'name',
  hash => ['resources', 'tasks' ]
;

use Carp;

use strict;
use vars qw($VERSION @ISA);

$VERSION = '0.01';

use RMA::Object;
@ISA = qw(RMA::Object);

# handles setting up id if necessary and calling _hash_init

sub init {
  my $self = shift;
  @_ = $self->SUPER::init(@_);
  $self->_hash_init(@_);
}

1;

=head1 AUTHOR

Sam Tregar, sam@tregar.com

=cut
